
dialogId("bot-m-vidis", "font_small", "Can you see that seahorse?")

dialogId("bot-v-uveznen0", "font_big", "It is blocked by amphoras.")

dialogId("bot-v-uveznen1", "font_big", "It got itself drunk among the amphoras.")

dialogId("bot-m-zajem", "font_small", "I wonder if there is anything left in them.")

dialogId("bot-v-podivat", "font_big", "You probably have to go check for yourself.")

dialogId("bot-m-vidim", "font_small", "Finally, I can see some new kind of skull.")

dialogId("bot-v-vsim", "font_big", "Did you notice that totem? It is the Mexican god Shelloxuatl.")

dialogId("bot-m-vypada", "font_small", "It looks like it.")

dialogId("bot-m-padaji", "font_small", "These amphores fall unbearably slow.")

dialogId("bot-v-vsak0", "font_big", "Well, you are not a bear, after all.")

dialogId("bot-v-vsak1", "font_big", "Don’t forget that we are under water.")

dialogId("bot-m-ble", "font_small", "Yuck. The authors could have spared us that animation.")

dialogId("bot-v-totem", "font_big", "This totem looks good to me.")

dialogId("bot-v-lebka", "font_big", "That skull seems to radiate something strange.")

dialogId("bot-m-zivy", "font_small", "Is it alive or is it some kind of spell?")

dialogId("bot-x-smich", "", "")

dialogId("bot-x-gr0", "", "")

dialogId("bot-x-gr1", "", "")
